@@ -55,12 +55,8 @@ void CWorkspace::init(PHLWORKSPACE self) {
     EMIT_HOOK_EVENT("createWorkspace", this);
 }
 
-SWorkspaceIDName CWorkspace::getPrevWorkspaceIDName() const {
-    return m_prevWorkspace;
-}
-
 CWorkspace::~CWorkspace() {
-    Debug::log(LOG, "Destroying workspace ID {}", m_id);
+    Log::logger->log(Log::DEBUG, "Destroying workspace ID {}", m_id);
 
     // check if g_pHookSystem and g_pEventManager exist, they might be destroyed as in when the compositor is closing.
     if (g_pHookSystem)
@@ -82,24 +78,6 @@ PHLWINDOW CWorkspace::getLastFocusedWindow() {
     return m_lastFocusedWindow.lock();
 }
 
-void CWorkspace::rememberPrevWorkspace(const PHLWORKSPACE& prev) {
-    if (!prev) {
-        m_prevWorkspace.id   = -1;
-        m_prevWorkspace.name = "";
-        return;
-    }
-
-    if (prev->m_id == m_id) {
-        Debug::log(LOG, "Tried to set prev workspace to the same as current one");
-        return;
-    }
-
-    m_prevWorkspace.id   = prev->m_id;
-    m_prevWorkspace.name = prev->m_name;
-
-    prev->m_monitor->addPrevWorkspaceID(prev->m_id);
-}
-
 std::string CWorkspace::getConfigName() {
     if (m_isSpecialWorkspace) {
         return m_name;
@@ -118,7 +96,7 @@ bool CWorkspace::matchesStaticSelector(const std::string& selector_) {
         return true;
 
     if (isNumber(selector)) {
-        const auto& [wsid, wsname] = getWorkspaceIDNameFromString(selector);
+        const auto& [wsid, wsname, isAutoID] = getWorkspaceIDNameFromString(selector);
 
         if (wsid == WORKSPACE_INVALID)
             return false;
@@ -156,14 +134,14 @@ bool CWorkspace::matchesStaticSelector(const std::string& selector_) {
             if (cur == 'r') {
                 WORKSPACEID from = 0, to = 0;
                 if (!prop.starts_with("r[") || !prop.ends_with("]")) {
-                    Debug::log(LOG, "Invalid selector {}", selector);
+                    Log::logger->log(Log::DEBUG, "Invalid selector {}", selector);
                     return false;
                 }
 
                 prop = prop.substr(2, prop.length() - 3);
 
                 if (!prop.contains("-")) {
-                    Debug::log(LOG, "Invalid selector {}", selector);
+                    Log::logger->log(Log::DEBUG, "Invalid selector {}", selector);
                     return false;
                 }
 
@@ -171,7 +149,7 @@ bool CWorkspace::matchesStaticSelector(const std::string& selector_) {
                 const auto LHS = prop.substr(0, DASHPOS), RHS = prop.substr(DASHPOS + 1);
 
                 if (!isNumber(LHS) || !isNumber(RHS)) {
-                    Debug::log(LOG, "Invalid selector {}", selector);
+                    Log::logger->log(Log::DEBUG, "Invalid selector {}", selector);
                     return false;
                 }
 
@@ -179,12 +157,12 @@ bool CWorkspace::matchesStaticSelector(const std::string& selector_) {
                     from = std::stoll(LHS);
                     to   = std::stoll(RHS);
                 } catch (std::exception& e) {
-                    Debug::log(LOG, "Invalid selector {}", selector);
+                    Log::logger->log(Log::DEBUG, "Invalid selector {}", selector);
                     return false;
                 }
 
                 if (to < from || to < 1 || from < 1) {
-                    Debug::log(LOG, "Invalid selector {}", selector);
+                    Log::logger->log(Log::DEBUG, "Invalid selector {}", selector);
                     return false;
                 }
 
@@ -195,7 +173,7 @@ bool CWorkspace::matchesStaticSelector(const std::string& selector_) {
 
             if (cur == 's') {
                 if (!prop.starts_with("s[") || !prop.ends_with("]")) {
-                    Debug::log(LOG, "Invalid selector {}", selector);
+                    Log::logger->log(Log::DEBUG, "Invalid selector {}", selector);
                     return false;
                 }
 
@@ -210,7 +188,7 @@ bool CWorkspace::matchesStaticSelector(const std::string& selector_) {
 
             if (cur == 'm') {
                 if (!prop.starts_with("m[") || !prop.ends_with("]")) {
-                    Debug::log(LOG, "Invalid selector {}", selector);
+                    Log::logger->log(Log::DEBUG, "Invalid selector {}", selector);
                     return false;
                 }
 
@@ -225,7 +203,7 @@ bool CWorkspace::matchesStaticSelector(const std::string& selector_) {
 
             if (cur == 'n') {
                 if (!prop.starts_with("n[") || !prop.ends_with("]")) {
-                    Debug::log(LOG, "Invalid selector {}", selector);
+                    Log::logger->log(Log::DEBUG, "Invalid selector {}", selector);
                     return false;
                 }
 
@@ -246,7 +224,7 @@ bool CWorkspace::matchesStaticSelector(const std::string& selector_) {
             if (cur == 'w') {
                 WORKSPACEID from = 0, to = 0;
                 if (!prop.starts_with("w[") || !prop.ends_with("]")) {
-                    Debug::log(LOG, "Invalid selector {}", selector);
+                    Log::logger->log(Log::DEBUG, "Invalid selector {}", selector);
                     return false;
                 }
 
@@ -284,14 +262,14 @@ bool CWorkspace::matchesStaticSelector(const std::string& selector_) {
                     // try single
 
                     if (!isNumber(prop)) {
-                        Debug::log(LOG, "Invalid selector {}", selector);
+                        Log::logger->log(Log::DEBUG, "Invalid selector {}", selector);
                         return false;
                     }
 
                     try {
                         from = std::stoll(prop);
                     } catch (std::exception& e) {
-                        Debug::log(LOG, "Invalid selector {}", selector);
+                        Log::logger->log(Log::DEBUG, "Invalid selector {}", selector);
                         return false;
                     }
 
@@ -314,7 +292,7 @@ bool CWorkspace::matchesStaticSelector(const std::string& selector_) {
                 const auto LHS = prop.substr(0, DASHPOS), RHS = prop.substr(DASHPOS + 1);
 
                 if (!isNumber(LHS) || !isNumber(RHS)) {
-                    Debug::log(LOG, "Invalid selector {}", selector);
+                    Log::logger->log(Log::DEBUG, "Invalid selector {}", selector);
                     return false;
                 }
 
@@ -322,12 +300,12 @@ bool CWorkspace::matchesStaticSelector(const std::string& selector_) {
                     from = std::stoll(LHS);
                     to   = std::stoll(RHS);
                 } catch (std::exception& e) {
-                    Debug::log(LOG, "Invalid selector {}", selector);
+                    Log::logger->log(Log::DEBUG, "Invalid selector {}", selector);
                     return false;
                 }
 
                 if (to < from || to < 1 || from < 1) {
-                    Debug::log(LOG, "Invalid selector {}", selector);
+                    Log::logger->log(Log::DEBUG, "Invalid selector {}", selector);
                     return false;
                 }
 
@@ -348,7 +326,7 @@ bool CWorkspace::matchesStaticSelector(const std::string& selector_) {
 
             if (cur == 'f') {
                 if (!prop.starts_with("f[") || !prop.ends_with("]")) {
-                    Debug::log(LOG, "Invalid selector {}", selector);
+                    Log::logger->log(Log::DEBUG, "Invalid selector {}", selector);
                     return false;
                 }
 
@@ -357,7 +335,7 @@ bool CWorkspace::matchesStaticSelector(const std::string& selector_) {
                 try {
                     FSSTATE = std::stoi(prop);
                 } catch (std::exception& e) {
-                    Debug::log(LOG, "Invalid selector {}", selector);
+                    Log::logger->log(Log::DEBUG, "Invalid selector {}", selector);
                     return false;
                 }
 
@@ -379,7 +357,7 @@ bool CWorkspace::matchesStaticSelector(const std::string& selector_) {
                 continue;
             }
 
-            Debug::log(LOG, "Invalid selector {}", selector);
+            Log::logger->log(Log::DEBUG, "Invalid selector {}", selector);
             return false;
         }
 
@@ -522,7 +500,7 @@ void CWorkspace::rename(const std::string& name) {
     if (g_pCompositor->isWorkspaceSpecial(m_id))
         return;
 
-    Debug::log(LOG, "CWorkspace::rename: Renaming workspace {} to '{}'", m_id, name);
+    Log::logger->log(Log::DEBUG, "CWorkspace::rename: Renaming workspace {} to '{}'", m_id, name);
     m_name = name;
 
     const auto WORKSPACERULE = g_pConfigManager->getWorkspaceRuleFor(m_self.lock());
@@ -542,7 +520,7 @@ void CWorkspace::updateWindows() {
         if (!w->m_isMapped || w->m_workspace != m_self)
             continue;
 
-        w->updateDynamicRules();
+        w->m_ruleApplicator->propertiesChanged(Desktop::Rule::RULE_PROP_ON_WORKSPACE);
     }
 }
 
