@@ -21,7 +21,7 @@ WP<CSyncTimeline> CDRMSyncPointState::timeline() {
 
 UP<CSyncReleaser> CDRMSyncPointState::createSyncRelease() {
     if (m_releaseTaken)
-        Debug::log(ERR, "CDRMSyncPointState: creating a sync releaser on an already created SyncRelease");
+        Log::logger->log(Log::ERR, "CDRMSyncPointState: creating a sync releaser on an already created SyncRelease");
 
     m_releaseTaken = true;
     return makeUnique<CSyncReleaser>(m_timeline, m_point);
@@ -180,7 +180,7 @@ CDRMSyncobjManagerResource::CDRMSyncobjManagerResource(UP<CWpLinuxDrmSyncobjMana
 
         SURF->m_syncobj = RESOURCE;
 
-        LOGM(LOG, "New linux_syncobj at {:x} for surface {:x}", (uintptr_t)RESOURCE.get(), (uintptr_t)SURF.get());
+        LOGM(Log::DEBUG, "New linux_syncobj at {:x} for surface {:x}", (uintptr_t)RESOURCE.get(), (uintptr_t)SURF.get());
     });
 
     m_resource->setImportTimeline([this](CWpLinuxDrmSyncobjManagerV1* r, uint32_t id, int32_t fd) {
@@ -192,7 +192,7 @@ CDRMSyncobjManagerResource::CDRMSyncobjManagerResource(UP<CWpLinuxDrmSyncobjMana
             return;
         }
 
-        LOGM(LOG, "New linux_drm_timeline at {:x}", (uintptr_t)RESOURCE.get());
+        LOGM(Log::DEBUG, "New linux_drm_timeline at {:x}", (uintptr_t)RESOURCE.get());
     });
 }
 
@@ -206,11 +206,11 @@ CDRMSyncobjProtocol::CDRMSyncobjProtocol(const wl_interface* iface, const int& v
     else if (g_pCompositor->m_drm.syncobjSupport)
         m_drmFD = g_pCompositor->m_drm.fd;
     else {
-        LOGM(ERR, "CDRMSyncobjProtocol: no nodes support explicit sync?");
+        LOGM(Log::ERR, "CDRMSyncobjProtocol: no nodes support explicit sync?");
         return;
     }
 
-    LOGM(LOG, "CDRMSyncobjProtocol: using fd {}", m_drmFD);
+    LOGM(Log::DEBUG, "CDRMSyncobjProtocol: using fd {}", m_drmFD);
 }
 
 void CDRMSyncobjProtocol::bindManager(wl_client* client, void* data, uint32_t ver, uint32_t id) {
